This concept is a bit more advanced than most of the other concepts in this guide. We've included this concept (and the following project) for those who are interested in some more advanced circuit theory concepts, but you should feel free to skip this concept and/or the next project if you find it overwhelming.

# Going Loopy

All of our first circuits contained just one loop — that is, just one path that ran from the positive side of the power source through some components and to the ground of the power source. In the real-world, circuits are generally more complicated than that, with lots of separate paths around the circuit running through lots of components. In fact, inside microprocessors, there are literally millions of interconnected wires and components, making millions and millions of tiny loops.

As an example, lets start with an example circuit we've seen before, a simple circuit that contains one loop and two components: a battery and a resistor.

When you add a new component to an existing circuit — assuming it has just two leads (legs) like a resistor does — there are two ways you can do it. The first way is that you can add the component in series with the other component:

Adding a component in series means that you are adding the component to the existing loop. You can add as many components as you want in series — it simply makes the loop bigger:

The second way to add a component to a circuit is to add the component in parallel with other components:

Adding a component in parallel means that you are creating a new loop (path) in the circuit. You can add as many components as you want in parallel — it simply adds more paths to the circuit:

Of course, you aren't limited to adding components only in series or only in parallel — you can do both to create more complex circuits that do more interesting things:

In the above case, resistors R1 and R2 are in parallel. Resistor R3 is in series with the combination of R1 and R2 together. And R4 is in parallel with the combination of R1, R2 and R3 together.

It's also worth noting that there are some types of components (like a computer chip) that have more than two leads (sometimes dozens or hundreds) — in these cases, we tend not to talk about series and parallel for that part of the circuit.

# Series & Parallel Resistance

So what happens when you add more resistance in series or parallel? Using the water analogy, we can get a good conceptual idea of what should happen.

When resistances are put in series, the total resistance adds up. This becomes important because, if you recall from our concept, when voltage stays the same, adding resistance to our circuit allows us to decrease the current (and removing resistance allows us to increase the current).

Here's an example:

PIC: Battery/2-resistor WATER series schematic

In the electric circuit above, the total resistance of the circuit now becomes R1 + R2. As you can probably now guess, putting two equal resistances in series gives exactly twice the resistance. And remembering back to our earlier discuss of Ohm's Law, if you keep the voltage the same in the circuit, doubling the resistance will cut the current in half.

On the other hand, when resistances are put in parallel, the total resistance is divided. Another way to say this is that the total current adds up — the current going into each of the branches is split between the branches proportional to the amount of resistance in the branch. Here's a picture:

PIC: Battery/2-resistor WATER parallel schematic

Without a little bit of math, this may be difficult to conceptualize, but the picture above should give you an idea. We don't want to get too mathy here, so hopefully our next project will make things a little clearer.